package datarecord;

import java.util.*;
import java.io.PrintStream;

/**
 * For simplicity, all DataSource and DataSink classes use a single
 * representation for data records in their buffers.
 * <br>This is it.
 * <br>A DataRecord is a byte[] plus two scalars: the total number of
 * bytes actually stored in that array, plus the current offset (i.e.,
 * the offset to the first byte not already handed out, if a DataSource,
 * or the first not yet written, if a DataSink.
 *
 * Note that the instance variables are all public.  This makes it easier
 * to call various Java API methods that read/write things like files
 * and network connections.  (Not to mention it avoids having to write
 * a slew of trivial getter/setter functions.)
 *
 * @version $Id: DataRecord.java,v 1.4 2010/01/05 07:59:07 zahorjan Exp $
 */

public class DataRecord {
  /**
   * The data
   */
  public byte[] data;
  /**
   * The size of the byte[] called data.
   */
  public int  capacity;
  /**
   * The number of unconsumed bytes of user data remaining in the buffer.
   */
  public int length;
  /**
   * An offset into the record.  For read(), the next byte to read.
   * For write()... not used for write().
   */
  public int  offset;

  /**
   * An instance variable of what would normally be a local
   * variable.  Done for the use of DataRecordManager,
   * to achieve blazing speed...
   */
  Integer mapKey;

  /**
   * Create the record and initialize to empty.  Package scope. (Should
   * be called only by DataRecordManager object.)
   */
  DataRecord(int size) {
    capacity = size;
    data = new byte[capacity];
    reInit();
  }

  /**
   * A method to initialize the portions of the DataRecord
   * that may have changed if it has previously been used.
   */
  void reInit() {
    offset = 0;
    length = 0;
  }

}