package datasource;

import java.io.IOException;
import java.io.FileNotFoundException;
import java.io.FileInputStream;

/**
 * A FileSource is a source that reads a file (sequentially);
 *
 * @version $Id: FileSource.java,v 1.7 2010/01/05 19:02:15 zahorjan Exp $
 */

public class FileSource extends DataSource {

  /**
   * The name of the file to read.
   */
  String filename;

  /**
   * The file object to read from.
   */
  FileInputStream file;

  /**
   * Open file for reading.
   */
  public FileSource(String fname) {
    filename = fname;
  }

  /**
   * (Re)Initialize this object.
   */
  public void reInit() throws IOException, FileNotFoundException {
    // try to open the file for reading
    file = new FileInputStream(filename);
    // start reader thread in DataSource
    readyToRead();
  }

  /**
   * Perform actual read from file.
   */
  protected int readFromSrc(byte[] buf, int len) throws IOException {
    int readLength = file.read(buf, 0, len);
    if ( readLength < 0 ) close();
    return readLength;
  }

  /**
   * Private function to close the file source.
   */

  private void close() throws IOException {
    file.close();
    file = null; // to cause an error if another read is attempted
  }
  
}
