package datasource;

import java.util.Arrays;
import java.io.IOException;

/**
 * A NullSource is a source that returns zeroes, as fast as it can.
 * It's so simple it needs no comments...
 *
 * @version $Id: NullSource.java,v 1.6 2010/01/05 19:02:15 zahorjan Exp $
 */

public class NullSource extends DataSource {
  /**
   * mySize is how many bytes this Null source should send in total.
   */
  private int mySize;
  /**
   * bytesLeftToSend is how many bytes remain to be sent this use
   * of this Null source.
   */
  private int bytesLeftToSend;

  public NullSource(int bytesToSend) {
    mySize = bytesToSend;
  }

  public void reInit() {
    bytesLeftToSend = mySize;
    readyToRead();  // start reader thread in DataSource
  }

  /**
   * We're a null source, so we don't actually read anything.
   * We just indicate whether or not all the bytes we represented
   * have been consumed.
   */
  protected int readFromSrc(byte[] buf, int len) {
    // we indicate end-of-data by returning a negative length
    if ( bytesLeftToSend <= 0 ) return -1;

    len = len <= bytesLeftToSend ? len : bytesLeftToSend;
    bytesLeftToSend -= len;
    return len;
  }
}
